@@ -5,7 +5,7 @@ from amino.maybe import Maybe, Just, Empty, may, flat_may, Nothing
 from amino.either import Left, Right, Either
 from amino.list import List, Lists
 from amino.boolean import Boolean
-from amino.anon import __, L, _
+from amino.anon.boot import __, L, _
 from amino.lazy_list import LazyList
 from amino.map import Map
 from amino.future import Future
@@ -17,6 +17,7 @@ from amino.eff import Eff
 from amino.eval import Eval
 from amino.regex import Regex
 from amino.options import integration_test, development
+from amino.do import do
 
 Path = pathlib.Path
 
@@ -24,4 +25,4 @@ boot()
 
 __all__ = ('Maybe', 'Just', 'Empty', 'may', 'List', 'Map', '_', 'Future', 'Boolean', 'development', 'flat_may',
            'curried', '__', 'Left', 'Right', 'Either', 'env', 'Try', 'LazyList', 'Logger', 'log', 'I', 'L', 'Eff',
-           'Task', 'Eval', 'Regex', 'Nothing', 'integration_test', 'Lists')
+           'Task', 'Eval', 'Regex', 'Nothing', 'integration_test', 'Lists', 'do')
