@@ -61,7 +61,7 @@ class List(Generic[A], typing.List[A], Implicits, implicits=True, metaclass=List
         return _rand_str(chars, num)
 
     @staticmethod
-    def gen(num: int, f: Callable[[], A]) -> 'List[A]':
+    def gen(num: int, f: Callable[[], 'List[A]']) -> 'List[A]':
         return List.range(num) // (lambda a: f())
 
     @staticmethod
@@ -76,19 +76,12 @@ class List(Generic[A], typing.List[A], Implicits, implicits=True, metaclass=List
         )
 
     def lift_all(self, index: int, *indexes: int) -> 'List[A]':
-        from amino.anon import _
         def folder(z: maybe.Maybe[List[A]], n: List[maybe.Maybe[A]]) -> maybe.Maybe[List[A]]:
-            return n.ap(z / _.cat)
+            return n.ap(z / (lambda a: a.cat))
         els = List.wrap(indexes) / self.lift
         init = self.lift(index) / List
         return els.fold_left(init)(folder)
 
-    def smap(self, f: Callable[..., B]) -> 'List[B]':
-        return List.wrap(list(itertools.starmap(f, self)))
-
-    def flat_smap(self, f: Callable[..., 'Iterable[B]']) -> 'List[B]':
-        return List.wrap(flatten(list(itertools.starmap(f, self))))
-
     def foreach(self, f: Callable[[A], B]) -> None:
         for el in self:
             f(el)
@@ -161,8 +154,7 @@ class List(Generic[A], typing.List[A], Implicits, implicits=True, metaclass=List
     __add__ = add
 
     def without(self, el: A) -> 'List[A]':
-        from amino.anon import _
-        return self.filter(_ != el)
+        return self.filter(lambda a: a != el)
 
     __sub__ = without
 
@@ -177,8 +169,7 @@ class List(Generic[A], typing.List[A], Implicits, implicits=True, metaclass=List
         return self.split(lambda a: isinstance(a, tpe))
 
     def index_of(self, target: Any) -> maybe.Maybe[int]:
-        from amino.anon import _
-        return self.index_where(_ == target)
+        return self.index_where(lambda a: a == target)
 
     @property
     def reversed(self) -> 'List[A]':
@@ -206,6 +197,9 @@ class List(Generic[A], typing.List[A], Implicits, implicits=True, metaclass=List
     def cons(self, item: A) -> 'List[A]':
         return List.wrap(cons(item, self))
 
+    def cons_m(self, item: maybe.Maybe[A]) -> 'List[A]':
+        return item / self.cons | self
+
     def cat(self, item: A) -> 'List[A]':
         return self + List(item)
 
@@ -272,14 +266,46 @@ class List(Generic[A], typing.List[A], Implicits, implicits=True, metaclass=List
         ws = ' ' * count
         return self.map(lambda a: f'{ws}{a}')
 
+    @property
+    def rstrip(self) -> 'List[str]':
+        return self / (lambda a: a.rstrip())
+
+    @property
+    def strip_newlines(self) -> 'List[str]':
+        return self / (lambda a: a.replace('\n', ''))
+
+    @property
+    def rstrip_newlines(self) -> 'List[str]':
+        return self / (lambda a: a.rstrip('\n'))
+
 
 class Lists:
-    wrap = List.wrap
-    range = List.range
-    random_string = List.random_string
-    random_alpha = List.random_alpha
-    gen = List.gen
-    lines = List.lines
+
+    @staticmethod
+    def wrap(l: Iterable[B]) -> List[B]:
+        return List(*list(l))
+
+    @staticmethod
+    def range(*a: int) -> List[int]:
+        return List.wrap(range(*a))
+
+    @staticmethod
+    def random_string(num: int=10) -> str:
+        chars = string.ascii_letters + string.digits
+        return _rand_str(chars, num)
+
+    @staticmethod
+    def random_alpha(num: int=10) -> str:
+        chars = string.ascii_letters
+        return _rand_str(chars, num)
+
+    @staticmethod
+    def gen(num: int, f: Callable[[], 'List[A]']) -> List[A]:
+        return List.range(num) // (lambda a: f())
+
+    @staticmethod
+    def lines(data: str) -> List[str]:
+        return List.wrap(data.splitlines())
 
     @staticmethod
     def split(data: str, splitter: str, maxsplit: int=-1) -> List[str]:
